#!/bin/sh
echo 'name: lens
version: 3.9.0.2
id: lens-3.9.0.2-98bd3157eaf5c8b5939ac5c131f16de8

license: BSD3
copyright: Copyright (C) 2012-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/lens/
package-url:
synopsis: Lenses, Folds and Traversals
description: This package comes \"Batteries Included\" with many useful lenses for the types
             commonly used from the Haskell Platform, and with tools for automatically
             generating lenses and isomorphisms for user-supplied data types.
             .
             The combinators in @Control.Lens@ provide a highly generic toolbox for composing
             families of getters, folds, isomorphisms, traversals, setters and lenses and their
             indexed variants.
             .
             An overview, with a large number of examples can be found in the @README@: <https://github.com/ekmett/lens#lens-lenses-folds-and-traversals>
             .
             A video on how to use lenses and how they are constructed is available from youtube: <http://youtu.be/cefnmjtAolY?hd=1>
             .
             Slides can be obtained here: <http://comonad.com/haskell/Lenses-Folds-and-Traversals-NYC.pdf>
             .
             More information on the care and feeding of lenses, including a brief tutorial and motivation
             for their types can be found on the lens wiki: <https://github.com/ekmett/lens/wiki>
             .
             A small game of @pong@ and other more complex examples that manage their state using lenses can be found in the example folder: <https://github.com/ekmett/lens/blob/master/examples/>
             .
             /Lenses, Folds and Traversals/
             .
             The core of the hierarchy of lens-like constructions looks like:
             .
             .
             <<http://i.imgur.com/4fHw3Fd.png>>
             .
             Local copy (<Hierarchy.png>)
             .
             You can compose any two elements of the hierarchy above using @(.)@ from the @Prelude@, and you can
             use any element of the hierarchy as any type it linked to above it.
             .
             The result is their lowest upper bound in the hierarchy (or an error if that bound doesn'\''t exist).
             .
             For instance:
             .
             * You can use any '\''Traversal'\'' as a '\''Fold'\'' or as a '\''Setter'\''.
             .
             * The composition of a '\''Traversal'\'' and a '\''Getter'\'' yields a '\''Fold'\''.
             .
             /Minimizing Dependencies/
             .
             If you want to provide lenses and traversals for your own types in your own libraries, then you
             can do so without incurring a dependency on this (or any other) lens package at all.
             .
             /e.g./ for a data type:
             .
             > data Foo a = Foo Int Int a
             .
             You can define lenses such as
             .
             > -- bar :: Lens'\'' (Foo a) Int
             > bar :: Functor f => (Int -> f Int) -> Foo a -> f (Foo a)
             > bar f (Foo a b c) = fmap (\a'\'' -> Foo a'\'' b c) (f a)
             .
             > -- baz :: Lens (Foo a) (Foo b) a b
             > quux :: Functor f => (a -> f b) -> Foo a -> f (Foo b)
             > quux f (Foo a b c) = fmap (Foo a b) (f c)
             .
             without the need to use any type that isn'\''t already defined in the @Prelude@.
             .
             And you can define a traversal of multiple fields with '\''Control.Applicative.Applicative'\'':
             .
             > -- traverseBarAndBaz :: Traversal'\'' (Foo a) Int
             > traverseBarAndBaz :: Applicative f => (Int -> f Int) -> Foo a -> f (Foo a)
             > traverseBarAndBaz f (Foo a b c) = Foo <$> f a <*> f b <*> pure c
             .
             What is provided in this library is a number of stock lenses and traversals for
             common haskell types, a wide array of combinators for working them, and more
             exotic functionality, (/e.g./ getters, setters, indexed folds, isomorphisms).
category: Data, Lenses
author: Edward A. Kmett
exposed: True
exposed-modules: Control.Exception.Lens Control.Lens
                 Control.Lens.Action Control.Lens.At Control.Lens.Combinators
                 Control.Lens.Cons Control.Lens.Each Control.Lens.Equality
                 Control.Lens.Fold Control.Lens.Getter Control.Lens.Indexed
                 Control.Lens.Internal Control.Lens.Internal.Action
                 Control.Lens.Internal.Bazaar Control.Lens.Internal.ByteString
                 Control.Lens.Internal.Context Control.Lens.Internal.Deque
                 Control.Lens.Internal.Exception Control.Lens.Internal.Fold
                 Control.Lens.Internal.Getter Control.Lens.Internal.Indexed
                 Control.Lens.Internal.Instances Control.Lens.Internal.Iso
                 Control.Lens.Internal.Level Control.Lens.Internal.Magma
                 Control.Lens.Internal.Prism Control.Lens.Internal.Review
                 Control.Lens.Internal.Setter Control.Lens.Internal.Zipper
                 Control.Lens.Internal.Zoom Control.Lens.Iso Control.Lens.Lens
                 Control.Lens.Level Control.Lens.Loupe Control.Lens.Operators
                 Control.Lens.Plated Control.Lens.Prism Control.Lens.Reified
                 Control.Lens.Review Control.Lens.Setter Control.Lens.Simple
                 Control.Lens.TH Control.Lens.Traversal Control.Lens.Tuple
                 Control.Lens.Type Control.Lens.Wrapped Control.Lens.Zipper
                 Control.Lens.Zoom Control.Monad.Error.Lens
                 Control.Parallel.Strategies.Lens Control.Seq.Lens Data.Array.Lens
                 Data.Bits.Lens Data.ByteString.Lens Data.ByteString.Strict.Lens
                 Data.ByteString.Lazy.Lens Data.Complex.Lens Data.Data.Lens
                 Data.Dynamic.Lens Data.HashSet.Lens Data.IntSet.Lens Data.List.Lens
                 Data.List.Split.Lens Data.Sequence.Lens Data.Set.Lens
                 Data.Text.Lens Data.Text.Strict.Lens Data.Text.Lazy.Lens
                 Data.Tree.Lens Data.Typeable.Lens Data.Vector.Lens
                 Data.Vector.Generic.Lens Generics.Deriving.Lens GHC.Generics.Lens
                 System.Exit.Lens System.FilePath.Lens System.IO.Error.Lens
                 Language.Haskell.TH.Lens Numeric.Lens
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/cabal/ghc-7.6.3/lens-3.9.0.2
library-dirs: /usr/local/lib/cabal/ghc-7.6.3/lens-3.9.0.2
              /usr/local/lib
hs-libraries: HSlens-3.9.0.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: MonadCatchIO-transformers-0.3.0.0-9df3c38f0408c0a91e2a32a7584ef9c9
         array-0.4.0.1-6380782b62ead58fec616aa07dc0e15c
         base-4.6.0.1-2324e29e8f7c561043683fccde7728aa
         bifunctors-3.2.0.1-6162296c903773aacd3b73cdae28f4b6
         bytestring-0.10.0.2-eecc198ed81abb69aaded5c195068445
         comonad-3.0.2-c9b20fae6ab04128f33052f7337a7c2e
         comonad-transformers-3.0.2-d8c0125e28c9fcf383f0f7177a41746a
         comonads-fd-3.0.1-7bd7468a6874c45b9f4cde5f2612969d
         containers-0.5.0.0-3b8b869ec10d44736414ab5bea776319
         contravariant-0.4-8d4f38894b776a59efc19a7fdebcc30a
         distributive-0.3.1-217a8d775c665e49cbd0305bb14038e9
         filepath-1.3.0.1-edbc3d8247914b04f448e9261e7fe895
         generic-deriving-1.5.0-2e4f9403220be2b791f3d442e242c387
         ghc-prim-0.3.0.0-00db43fcd2f6e2a73243bdb496b765e0
         hashable-1.1.2.5-93ac9e8f4902e70447854e208345383a
         mtl-2.1.2-735d9c92b4f214d454fb5168bb1eb6ee
         parallel-3.2.0.3-e820b19f5a9c77af99f9f74ca067f604
         profunctor-extras-3.3-84dfd54dca681d4e09327a666c14c15d
         profunctors-3.3.0.1-5c92fa5294a1f24165f12239058df123
         reflection-1.3.2-b5c429618fd83bd001c91b7f3a5e39d5
         semigroupoids-3.0.2-b3fe89077f983e1986dfb42367f2f870
         semigroups-0.9.1-1de38af292cda5d8013fb8ed9ce095e0
         split-0.2.2-da1c8aaae88e58aebda2b8c3fd552806
         tagged-0.6-7d73f52235c53f67928eb3a120111ee7
         template-haskell-2.8.0.0-3b2af6051fa6bc928fdd2313c263ded3
         text-0.11.3.1-e3fd09aac6fbf908855282746125e0ed
         transformers-0.3.0.0-948c0bbaafc952a144be4248ffa27cb1
         unordered-containers-0.2.3.1-2ea5bcb5e4ac7f1608cee1deab4d4e38
         vector-0.10.0.1-8398066fa66cdbff397fa1d47fe95cbe
         void-0.6-bfa8bcec991f9caee4dbdf54caf44448
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/cabal/ghc-7.6.3/lens-3.9.0.2/html/lens.haddock
haddock-html: /usr/local/share/doc/cabal/ghc-7.6.3/lens-3.9.0.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
